from typing import Any, List
import lichess.api as lichess_api
from lichess.format import PGN

class LichessExtractor:
    def extract_games(self, username: str) -> List[Any]:
        return list(lichess_api.user_games(username, max=2, clocks=True, evals=True, opening=True, format=PGN))
        


#!/usr/bin/env python

import argparse
from extractors import *

def main():
    parser = argparse.ArgumentParser(description='Extract your chess games data from https://lichess.org and https://chess.com.')
    parser.add_argument('username', help='The username of the player.', nargs=1)
    parser.add_argument('--include-casual', const=True, default=False, nargs='?', help='Include casual games. By default only rated games are downloaded.')
    parser.add_argument('-w', '--website', choices=['lichess', 'chessdotcom', 'both'], default='both', nargs='?', help='The website to extract the data from. Default value is "both".')
    
    args = parser.parse_args()
    games = []
    if args.website == 'both' or args.website == 'lichess':
        extractor = LichessExtractor()
        games.extend(extractor.extract_games(args.username[0]))
    if args.website == 'both' or args.website == 'chessdotcom':
        extractor = ChessdotcomExtractor()
        games.extend(extractor.extract_games(args.username[0]))

    f = open(args.username[0], "w")
    f.write('\n'.join(games))
    f.close()

if __name__ == '__main__':
	main()


from typing import Any, List
from datetime import datetime, date
from dateutil import rrule
import chessdotcom as chesscom

class ChessdotcomExtractor:
    def extract_games(self, username: str) -> List[Any]:
        profile = chesscom.get_player_profile(username)
        start_date = datetime.fromtimestamp(profile.player.joined)
        start_date = date(start_date.year, start_date.month, 1)
        now = datetime.now()
        now = date(now.year, now.month, 1)
        print('start_date', start_date, profile)
        games = []
        for dt in rrule.rrule(rrule.MONTHLY, dtstart=start_date, until=now):
            response = chesscom.get_player_games_by_month(username=username, month=dt.month, year=dt.year)
            if response.json['games']:
                games.extend(list(map(lambda x: x['pgn'], response.json['games'])))
        return games



from setuptools import setup, find_namespace_packages
from os.path import abspath, dirname, join

# Fetches the content from README.md
# This will be used for the "long_description" field.
README_MD = open(join(dirname(abspath(__file__)), "README.md")).read()

setup(
    name="chessfessor",
    version="1.0.7",
    packages=find_namespace_packages(include=['chessfessor', 'chessfessor.*'], exclude=['*.tests*']),
    description="Extract your chess games data from https://lichess.org and https://chess.com",
    long_description=README_MD,
    long_description_content_type="text/markdown",
    url="https://github.com/FrequentlyMissedDeadlines/py-chessfessor",
    author="FrequentlyMissedDeadlines",
    author_email="FrequentlyMissedDeadlines+chessfessor@gmail.com",

    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: End Users/Desktop",
        "Natural Language :: English",
        "Topic :: Games/Entertainment :: Board Games",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10"
    ],

    entry_points={
        'console_scripts': [
            'chessfessor=chessfessor.chessfessor:main',
        ],
    },
    project_urls={
        'Bug Reports': 'https://github.com/FrequentlyMissedDeadlines/py-chessfessor/issues',
        'Source': 'https://github.com/FrequentlyMissedDeadlines/py-chessfessor',
    },
)